@@ -234,7 +234,7 @@ class ModelConfig(BaseModel):
 DEFAULT_PROVIDERS = [
     ProviderConfig(
         name="onlysq",
-        api_base="https://api.onlysq.ru/ai/openai",
+        api_base="https://api.onlysq.ru/ai/openai/",
         api_key_env_var="ONLYSQ_API_KEY",
         backend=Backend.GENERIC,
         supports_streaming_with_tools=False,  # OnlySq returns empty when streaming + tools
@@ -253,32 +253,47 @@ DEFAULT_MODELS = [
         name="gemini-3-pro",
         provider="onlysq",
         alias="gemini-3-pro",
+        input_price=0.0,
+        output_price=0.0,
     ),
     ModelConfig(
         name="gpt-5.1",
         provider="onlysq",
         alias="gpt-5.1",
+        input_price=0.0,
+        output_price=0.0,
+        supports_tools=False,
     ),
     ModelConfig(
         name="zai-glm-4-5",
         provider="onlysq",
         alias="zai-glm-4-5",
+        input_price=0.0,
+        output_price=0.0,
+        supports_tools=False,
     ),
     ModelConfig(
         name="qwen3-coder-480b-a35b",
         provider="onlysq",
         alias="qwen3-coder-480b-a35b",
+        input_price=0.0,
+        output_price=0.0,
+        supports_tools=False,
     ),
     ModelConfig(
         name="qwen3-235b-a22b-thinking",
         provider="onlysq",
         alias="qwen3-235b-a22b-thinking",
+        input_price=0.0,
+        output_price=0.0,
         supports_tools=False,
     ),
     ModelConfig(
         name="kimi-k2-thinking",
         provider="onlysq",
         alias="kimi-k2-thinking",
+        input_price=0.0,
+        output_price=0.0,
         supports_tools=False,
     ),
 ]
@@ -556,6 +571,13 @@ class DecoderConfig(BaseSettings):
             if not found:
                 config.models.append(default_model)
 
+        # Sync providers
+        for default_provider in DEFAULT_PROVIDERS:
+            for existing in config.providers:
+                if existing.name == default_provider.name:
+                    existing.api_base = default_provider.api_base
+                    break
+
         return config
 
     @classmethod
